@@ -1,10 +1,15 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 
 use strict;
 use warnings;
 
 package Mail::Box;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.082';
+
 use base 'Mail::Reporter';
 
 use Mail::Box::Message;
@@ -16,12 +21,10 @@ use Scalar::Util 'weaken';
 use List::Util   qw/sum first/;
 
 #-------------------------------------------
-# Clean exist required to remove lockfiles and to save changes.
+# Clean exits required to remove lockfiles and to save changes.
 
 $SIG{INT} = $SIG{QUIT} = $SIG{PIPE} = $SIG{TERM} = sub {exit 0};
 
-#-------------------------------------------
-
 
 #-------------------------------------------
 
@@ -407,13 +410,9 @@ sub writable()  {shift->{MB_access} =~ /w|a|d/ }
 sub writeable() {shift->writable}  # compatibility [typo]
 sub readable()  {1}  # compatibility
 
-#-------------------------------------------
-
 
 sub access()    {shift->{MB_access}}
 
-#-------------------------------------------
-
 
 sub modified(;$)
 {   my $self = shift;
@@ -427,8 +426,6 @@ sub modified(;$)
     0;
 }
 
-#-------------------------------------------
-
 
 sub isModified()
 {   my $self     = shift;
@@ -450,8 +447,6 @@ sub message(;$$)
     @_ ?  $self->{MB_messages}[$index] = shift : $self->{MB_messages}[$index];
 }
 
-#-------------------------------------------
-
 
 sub messageId($;$)
 {   my ($self, $msgid) = (shift, shift);
@@ -500,8 +495,6 @@ sub messageId($;$)
 
 sub messageID(@) {shift->messageId(@_)} # compatibility
 
-#-------------------------------------------
-
 
 sub find($)
 {   my ($self, $msgid) = (shift, shift);
@@ -522,8 +515,6 @@ sub find($)
     $msgids->{$msgid};
 }
 
-#-------------------------------------------
-
 
 sub messages($;$)
 {   my $self = shift;
@@ -556,20 +547,14 @@ sub messages($;$)
     grep {$action->($_)} @{$self->{MB_messages}};
 }
 
-#-------------------------------------------
-
 
 sub nrMessages(@) { scalar shift->messages(@_) }
 
-#-------------------------------------------
-
 
 sub messageIds()    { map {$_->messageId} shift->messages }
 sub allMessageIds() {shift->messageIds}  # compatibility
 sub allMessageIDs() {shift->messageIds}  # compatibility
 
-#-------------------------------------------
-
 
 sub current(;$)
 {   my $self = shift;
@@ -599,8 +584,6 @@ sub current(;$)
     $next;
 }
 
-#-------------------------------------------
-
 
 sub scanForMessages($$$$)
 {   my ($self, $startid, $msgids, $moment, $window) = @_;
@@ -613,8 +596,7 @@ sub scanForMessages($$$$)
     my $nr_messages = $self->messages
         or return keys %search; 
 
-    my $startmsg = $self->messageId($startid)
-        if defined $startid;
+    my $startmsg = defined $startid ? $self->messageId($startid) : undef;
 
     # Set-up window-bound.
     my $bound = 0;
@@ -647,8 +629,6 @@ sub scanForMessages($$$$)
     keys %search;
 }
 
-#-------------------------------------------
-
 
 sub findFirstLabeled($;$$)
 {   my ($self, $label, $set, $msgs) = @_;
@@ -668,29 +648,23 @@ sub findFirstLabeled($;$$)
 
 sub listSubFolders(@) { () }   # by default no sub-folders
 
-#-------------------------------------------
-
 
 sub openRelatedFolder(@)
 {   my $self    = shift;
     my @options = (%{$self->{MB_init_options}}, @_);
 
     $self->{MB_manager}
-    ? $self->{MB_manager}->open(@options)
+    ? $self->{MB_manager}->open(type => ref($self), @options)
     : (ref $self)->new(@options);
 }
 
-#-------------------------------------------
-
 
 sub openSubFolder($@)
-{   my $self    = shift;
-    my $name    = $self->nameOfSubFolder(shift);
+{   my $self = shift;
+    my $name = $self->nameOfSubFolder(shift);
     $self->openRelatedFolder(@_, folder => $name);
 }
 
-#-------------------------------------------
-
 
 sub nameOfSubFolder($;$)
 {   my ($thing, $name) = (shift, shift);
@@ -698,8 +672,6 @@ sub nameOfSubFolder($;$)
     defined $parent ? "$parent/$name" : $name;
 }
 
-#-------------------------------------------
-
 
 sub topFolderWithMessages() { 1 }
 
@@ -771,8 +743,6 @@ sub write(@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub determineBodyType($$)
 {   my ($self, $message, $head) = @_;
@@ -797,8 +767,6 @@ sub lazyPermitted($)
     $self->{MB_lazy_permitted} = shift;
 }
 
-#-------------------------------------------
-
 
 sub storeMessage($)
 {   my ($self, $message) = @_;
@@ -808,8 +776,6 @@ sub storeMessage($)
     $message;
 }
 
-#-------------------------------------------
-
 
 my %seps = (CR => "\015", LF => "\012", CRLF => "\015\012");
 
@@ -825,15 +791,9 @@ sub lineSeparator(;$)
    $sep;
 }
 
-#-------------------------------------------
-
 
 sub create($@) {shift->notImplemented}
 
-#-------------------------------------------
-
-
-#-------------------------------------------
 
 
 sub coerce($@)
@@ -842,28 +802,18 @@ sub coerce($@)
     $message->isa($mmtype) ? $message : $mmtype->coerce($message, @_);
 }
 
-#-------------------------------------------
-
 
 sub readMessages(@) {shift->notImplemented}
 
-#-------------------------------------------
-
 
 sub updateMessages(@) { shift }
 
-#-------------------------------------------
-
 
 sub writeMessages(@) {shift->notImplemented}
 
-#-------------------------------------------
-
 
 sub locker() { shift->{MB_locker} }
 
-#-------------------------------------------
-
 
 sub toBeThreaded(@)
 {   my $self = shift;
@@ -875,8 +825,6 @@ sub toBeThreaded(@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub toBeUnthreaded(@)
 {   my $self = shift;
