@@ -1,11 +1,12 @@
-# Copyrights 2001-2007 by Mark Overmeer.
-# For other contributors see ChangeLog.
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.04.
 
 package Mail::Box::File;
 use vars '$VERSION';
-$VERSION = '2.070';
+$VERSION = '2.082';
+
 use base 'Mail::Box';
 
 use strict;
@@ -100,8 +101,6 @@ sub init($)
     :                              undef;
 }
 
-#-------------------------------------------
-
 
 sub create($@)
 {   my ($thingy, $name, %args) = @_;
@@ -136,8 +135,6 @@ sub create($@)
     $class;
 }
 
-#-------------------------------------------
-
 sub foundIn($@)
 {   my $class = shift;
     my $name  = @_ % 2 ? shift : undef;
@@ -150,19 +147,13 @@ sub foundIn($@)
     -f $filename;
 }
 
-#-------------------------------------------
-
 sub organization() { 'FILE' }
 
-#-------------------------------------------
-
 sub size()
 {   my $self = shift;
     $self->isModified ? $self->SUPER::size : -s $self->filename;
 }
 
-#-------------------------------------------
-
 sub close(@)
 {   my $self = $_[0];            # be careful, we want to set the calling
     undef $_[0];                 #    ref to undef, as the SUPER does.
@@ -175,8 +166,6 @@ sub close(@)
     $rc;
 }
 
-#-------------------------------------------
-
 
 sub appendMessages(@)
 {   my $class  = shift;
@@ -250,8 +239,6 @@ sub parser()
     $parser;
 }
 
-#-------------------------------------------
-
 sub readMessages(@)
 {   my ($self, %args) = @_;
 
@@ -267,8 +254,6 @@ sub readMessages(@)
     $self->updateMessages;
 }
  
-#-------------------------------------------
-
 
 sub updateMessages(@)
 {   my ($self, %args) = @_;
@@ -299,8 +284,6 @@ sub updateMessages(@)
     $self;
 }
 
-#-------------------------------------------
-
 
 sub messageCreateOptions(@)
 {   my ($self, @options) = @_;
@@ -312,8 +295,6 @@ sub messageCreateOptions(@)
     @{$self->{MBF_create_options}};
 }
 
-#-------------------------------------------
-
 
 sub moveAwaySubFolder($$)
 {   my ($self, $dir, $extension) = @_;
@@ -322,16 +303,12 @@ sub moveAwaySubFolder($$)
     $self;
 }
 
-#-------------------------------------------
-
 sub delete(@)
 {   my $self = shift;
     $self->SUPER::delete(@_);
     unlink $self->filename;
 }
 
-#-------------------------------------------
-
 
 sub writeMessages($)
 {   my ($self, $args) = @_;
@@ -429,7 +406,14 @@ sub _write_replace($)
     $old->close && $ok
         or return 0;
 
-    unlink $filename if $windows;
+    if($windows)
+    {   # Windows does not like to move to existing filenames
+        unlink $filename;
+
+        # Windows cannot move to files which are opened.
+        $self->parser->closeFile;
+    }
+
     unless(move $tmpnew, $filename)
     {   $self->log(WARNING =>
             "Cannot replace $filename by $tmpnew, to update folder $self: $!");
