@@ -1,12 +1,16 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 
 use strict;
 package Mail::Box::File::Message;
 use vars '$VERSION';
-$VERSION = '2.063';
+$VERSION = '2.082';
+
 use base 'Mail::Box::Message';
 
-use POSIX 'SEEK_SET';
-use Carp;
+use List::Util   qw/sum/;
 
 
 sub init($)
@@ -19,30 +23,32 @@ sub init($)
     $self;
 }
 
-#------------------------------------------
-
 sub coerce($)
 {   my ($self, $message) = @_;
     return $message if $message->isa(__PACKAGE__);
     $self->SUPER::coerce($message)->labelsToStatus;
 }
 
-#-------------------------------------------
-
 
 sub write(;$)
 {   my $self  = shift;
     my $out   = shift || select;
 
+    my $escaped = $self->escapedBody;
     $out->print($self->fromLine);
-    $self->head->print($out);
-    $self->body->printEscapedFrom($out);
+
+    my $size  = sum map {length($_)} @$escaped;
+
+    my $head  = $self->head;
+    $head->set('Content-Length' => $size); 
+    $head->set('Lines' => scalar @$escaped);
+    $head->print($out);
+
+    $out->print($_) for @$escaped;
     $out->print("\n");
     $self;
 }
 
-#-------------------------------------------
-
 sub clone()
 {   my $self  = shift;
     my $clone = $self->SUPER::clone;
@@ -60,6 +66,13 @@ sub fromLine(;$)
     $self->{MBMM_from_line} ||= $self->head->createFromLine;
 }
 
+
+sub escapedBody()
+{   my @lines = shift->body->lines;
+    s/^(\>*From )/>$1/ for @lines;
+    \@lines;
+}
+
 #------------------------------------------
 
 
@@ -75,12 +88,8 @@ sub readFromParser($)
     $self;
 }
 
-#-------------------------------------------
-
 sub loadHead() { shift->head }
 
-#-------------------------------------------
-
 
 sub loadBody()
 {   my $self     = shift;
@@ -105,8 +114,6 @@ sub loadBody()
     $newbody;
 }
 
-#-------------------------------------------
-
 
 sub fileLocation()
 {   my $self = shift;
@@ -116,8 +123,6 @@ sub fileLocation()
      : $self->{MBMM_begin};
 }
 
-#------------------------------------------
-
 
 sub moveLocation($)
 {   my ($self, $dist) = @_;
