@@ -1,10 +1,15 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 
 use strict;
 use warnings;
 
 package Mail::Box::IMAP4;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.082';
+
 use base 'Mail::Box::Net';
 
 use Mail::Box::IMAP4::Message;
@@ -25,7 +30,7 @@ sub init($)
 
     # MailBox names top folder directory '=', but IMAP needs '/'
     $folder = '/'
-       if $folder eq '=';
+        if $folder eq '=';
 
     # There's a disconnect between the URL parser and this code.
     # The URL parser always produces a full path (beginning with /)
@@ -43,38 +48,36 @@ sub init($)
     my $access    = $args->{access} ||= 'r';
     my $writeable = $access =~ m/w|a/;
     my $ch        = $self->{MBI_c_head}
-       = $args->{cache_head} || ($writeable ? 'NO' : 'DELAY');
+      = $args->{cache_head} || ($writeable ? 'NO' : 'DELAY');
 
     $args->{head_type} ||= 'Mail::Box::IMAP4::Head'
-       if $ch eq 'NO' || $ch eq 'PARTIAL';
+        if $ch eq 'NO' || $ch eq 'PARTIAL';
 
     $args->{body_type}  ||= 'Mail::Message::Body::Lines';
 
     $self->SUPER::init($args);
 
     $self->{MBI_domain}   = $args->{domain};
-    $self->{MBI_c_labels} = $args->{cache_labels}
-                         || ($writeable  ? 'NO' : 'DELAY');
-    $self->{MBI_c_body}   = $args->{cache_body}
-                         || ($writeable ? 'NO' : 'DELAY');
+    $self->{MBI_c_labels}
+      = $args->{cache_labels} || ($writeable ? 'NO' : 'DELAY');
+    $self->{MBI_c_body}
+      = $args->{cache_body}   || ($writeable ? 'NO' : 'DELAY');
 
 
     my $transport = $args->{transporter} || 'Mail::Transport::IMAP4';
     $transport = $self->createTransporter($transport, %$args)
-       unless ref $transport;
+        unless ref $transport;
 
     $self->transporter($transport);
 
     defined $transport
-       or return;
+        or return;
 
       $args->{create}
     ? $self->create($transport, $args)
     : $self;
 }
 
-#-------------------------------------------
-
 sub create($@)
 {   my($self, $name, $args) =  @_;
 
@@ -87,8 +90,6 @@ sub create($@)
     $self->transporter->createFolder($name);
 }
 
-#-------------------------------------------
-
 sub foundIn(@)
 {   my $self = shift;
     unshift @_, 'folder' if @_ % 2;
@@ -98,12 +99,8 @@ sub foundIn(@)
     || (exists $options{folder} && $options{folder} =~ m/^imap/);
 }
 
-#-------------------------------------------
-
 sub type() {'imap4'}
 
-#-------------------------------------------
-
 
 sub close(@)
 {   my $self = shift;
@@ -112,8 +109,6 @@ sub close(@)
     $self;
 }
 
-#-------------------------------------------
-
 sub listSubFolders(@)
 {   my ($thing, %args) = @_;
     my $self = $thing;
@@ -125,8 +120,6 @@ sub listSubFolders(@)
     defined $imap ? $imap->folders($self) : ();
 }
 
-#-------------------------------------------
-
 sub nameOfSubfolder($;$) { $_[1] }
 
 #-------------------------------------------
@@ -179,8 +172,6 @@ sub readMessages(@)
     $self;
 }
  
-#-------------------------------------------
-
 
 sub getHead($)
 {   my ($self, $message) = @_;
@@ -201,8 +192,6 @@ sub getHead($)
     $head;
 }
 
-#-------------------------------------------
-
 
 sub getHeadAndBody($)
 {   my ($self, $message) = @_;
@@ -240,8 +229,6 @@ sub getHeadAndBody($)
     ($head, $body->contentInfoFrom($head));
 }
 
-#-------------------------------------------
-
 
 sub body(;$)
 {   my $self = shift;
@@ -253,9 +240,6 @@ sub body(;$)
     $self->SUPER::body(@_);
 }
 
-#-------------------------------------------
-
-
 
 sub write(@)
 {   my ($self, %args) = @_;
@@ -264,15 +248,13 @@ sub write(@)
     $self->SUPER::write(%args, transporter => $imap) or return;
 
     if($args{save_deleted})
-    {   $self->log(NOTICE => "Impossible to keep deleted messages in IMAP")
+    {   $self->log(NOTICE => "Impossible to keep deleted messages in IMAP");
     }
-    else { $imap->destroyDeleted }
+    else { $imap->destroyDeleted($self->name) }
 
     $self;
 }
 
-#-------------------------------------------
-
 sub delete(@)
 {   my $self   = shift;
     my $transp = $self->transporter;
@@ -280,8 +262,6 @@ sub delete(@)
     $transp->deleteFolder($self->name);
 }
 
-#-------------------------------------------
-
 
 sub writeMessages($@)
 {   my ($self, $args) = @_;
@@ -294,8 +274,6 @@ sub writeMessages($@)
     $self;
 }
 
-#-------------------------------------------
-
 
 my %transporters;
 sub createTransporter($@)
@@ -328,8 +306,6 @@ sub createTransporter($@)
     $transporter;
 }
 
-#-------------------------------------------
-
 
 sub transporter(;$)
 {   my $self = shift;
@@ -358,8 +334,6 @@ sub transporter(;$)
     undef;
 }
 
-#-------------------------------------------
-
 
 sub fetch($@)
 {   my ($self, $what, @info) = @_;
