@@ -1,7 +1,12 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 
 package Mail::Box::Mbox;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.082';
+
 use base 'Mail::Box::File';
 
 use strict;
@@ -22,8 +27,6 @@ sub init($)
     $self->SUPER::init($args);
 }
 
-#-------------------------------------------
-
 
 sub create($@)
 {   my ($thingy, $name, %args) = @_;
@@ -34,8 +37,6 @@ sub create($@)
     $class->SUPER::create($name, %args);
 }
 
-#-------------------------------------------
-
 
 sub foundIn($@)
 {   my $class = shift;
@@ -47,9 +48,20 @@ sub foundIn($@)
     my $extension = $args{subfolder_extension} || $default_sub_extension;
     my $filename  = $class->folderToFilename($name, $folderdir, $extension);
 
-    if(-d $filename)      # fake empty folder, with sub-folders
-    {   return 1 unless -f File::Spec->catfile($filename, '1')   # MH
-                     || -d File::Spec->catdir($filename, 'cur'); # Maildir
+    if(-d $filename)
+    {   # Maildir and MH Sylpheed have a 'new' sub-directory
+        return 0 if -d File::Spec->catdir($filename, 'new');
+        local *DIR;
+        if(opendir DIR, $filename)
+        {    my @f = grep !/^\./, readdir DIR;   # skip . .. and hidden
+             return 0 if @f && ! grep /\D/, @f;              # MH
+             closedir DIR;
+        }
+
+        return 0                                             # Other MH
+            if -f "$filename/.mh_sequences";
+
+        return 1;      # faked empty Mbox sub-folder (with subsub-folders?)
     }
 
     return 0 unless -f $filename;
@@ -66,8 +78,6 @@ sub foundIn($@)
     return 1;
 }
 
-#-------------------------------------------
-
 sub delete(@)
 {   my $self = shift;
     $self->SUPER::delete(@_);
@@ -76,8 +86,6 @@ sub delete(@)
     rmdir $subfdir;   # may fail, when there are still subfolders (no recurse)
 }
 
-#-------------------------------------------
-
 sub writeMessages($)
 {   my ($self, $args) = @_;
 
@@ -93,12 +101,8 @@ sub writeMessages($)
     $self;
 }
 
-#-------------------------------------------
-
 sub type() {'mbox'}
 
-#-------------------------------------------
-
 
 sub listSubFolders(@)
 {   my ($thingy, %args)  = @_;
@@ -113,6 +117,7 @@ sub listSubFolders(@)
                    : $default_folder_dir;
 
     my $extension  = $args{subfolder_extension};
+
     my $dir;
     if(ref $thingy)   # Mail::Box::Mbox
     {    $extension ||= $thingy->{MBM_sub_ext};
@@ -123,8 +128,10 @@ sub listSubFolders(@)
          $dir = $class->folderToFilename($folder, $folderdir, $extension);
     }
 
-    my $real       = -d $dir ? $dir : "$dir$extension";
-    return () unless opendir DIR, $real;
+    my $real  = -d $dir ? $dir : "$dir$extension";
+
+    opendir DIR, $real
+        or return ();
 
     # Some files have to be removed because they are created by all
     # kinds of programs, but are no folders.
@@ -141,8 +148,7 @@ sub listSubFolders(@)
 
     foreach (@entries)
     {   my $entry = File::Spec->catfile($real, $_);
-        next unless -r $entry;
-        if( -f _ )
+        if( -f $entry )
         {   next if $args{skip_empty} && ! -s _;
             next if $args{check} && !$class->foundIn($entry);
             $folders{$_}++;
@@ -183,7 +189,7 @@ sub folderToFilename($$;$)
     {   my $file  = pop @parts;
 
         $real = File::Spec->catdir($real.(-d $real ? '' : $extension), $_) 
-           foreach @parts;
+            foreach @parts;
 
         $real = File::Spec->catfile($real.(-d $real ? '' : $extension), $file);
     }
