@@ -1,10 +1,15 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 
 use strict;
 use warnings;
 
 package Mail::Box::Message;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.082';
+
 use base 'Mail::Message';
 
 use Date::Parse;
@@ -15,30 +20,16 @@ sub init($)
 {   my ($self, $args) = @_;
     $self->SUPER::init($args);
 
-    $self->{MBM_body_type}  = $args->{body_type}
-        if exists $args->{body_type};
-
-    $self->{MBM_folder}     = $args->{folder};
+    $self->{MBM_body_type} = $args->{body_type};
+    $self->{MBM_folder}    = $args->{folder};
     weaken($self->{MBM_folder});
 
     return $self if $self->isDummy;
-
     $self;
 }
 
 #-------------------------------------------
 
-
-sub coerce($)
-{   my ($class, $message) = @_;
-    return bless $message, $class
-        if $message->isa(__PACKAGE__);
-
-    $class->SUPER::coerce($message);
-}
-
-#-------------------------------------------
-
 sub head(;$)
 {   my $self  = shift;
     return $self->SUPER::head unless @_;
@@ -77,28 +68,28 @@ sub folder(;$)
     $self->{MBM_folder};
 }
 
-#-------------------------------------------
-
 
 sub seqnr(;$)
 {   my $self = shift;
     @_ ? $self->{MBM_seqnr} = shift : $self->{MBM_seqnr};
 }
 
-#-------------------------------------------
 
+sub copyTo($@)
+{   my ($self, $folder) = (shift, shift);
+    my $clone = $self->clone(@_);
 
-sub copyTo($)
-{   my ($self, $folder) = @_;
-    $folder->addMessage($self->clone);
+    $folder->addMessage($clone);
 }
 
-#-------------------------------------------
 
+sub moveTo($@)
+{   my ($self, $folder, %args) = @_;
 
-sub moveTo($)
-{   my ($self, $folder) = @_;
-    my $added = $folder->addMessage($self->clone);
+    $args{share} = 1
+        unless exists $args{share} || exists $args{shallow_body};
+
+    my $added = $self->copyTo($folder, %args);
     $self->label(deleted => 1);
     $added;
 }
@@ -111,19 +102,15 @@ sub readBody($$;$)
 
     unless($getbodytype)
     {   my $folder   = $self->{MBM_folder};
-        $getbodytype = sub {$folder->determineBodyType(@_)};
+        $getbodytype = sub {$folder->determineBodyType(@_)} if defined $folder;
     }
 
     $self->SUPER::readBody($parser, $head, $getbodytype);
 }
 
-#-------------------------------------------
-
 
 sub diskDelete() { shift }
 
-#-------------------------------------------
-
 sub forceLoad() {   # compatibility
    my $self = shift;
    $self->loadBody(@_);
