@@ -1,13 +1,14 @@
-# Copyrights 2001-2007 by Mark Overmeer.
-# For other contributors see ChangeLog.
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.04.
 
 use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.070';
+$VERSION = '2.082';
+
 
 use Mail::Message::Head::Complete  ();
 use Mail::Message::Body::Lines     ();
@@ -62,7 +63,8 @@ sub build(@)
         {   @data = map {Mail::Message::Body->new(file => $_) } @$value }
         elsif($key eq 'attach')
         {   foreach my $c (ref $value eq 'ARRAY' ? @$value : $value)
-	    {   push @data, $c->isa('Mail::Message')
+	    {   defined $c or next;
+                push @data, ref $c && $c->isa('Mail::Message')
 		          ? Mail::Message::Body::Nested->new(nested => $c)
 			  : $c;
             }
