@@ -1,9 +1,14 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 
 use strict;
 
 package Mail::Message;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.082';
+
 
 use IO::Lines;
 
@@ -36,8 +41,6 @@ sub file()
     $file;
 }
 
-#------------------------------------------
-
 
 sub printStructure(;$$)
 {   my $self    = shift;
@@ -55,7 +58,7 @@ sub printStructure(;$$)
     my $subject = $self->get('Subject') || '';
     $subject    = ": $subject" if length $subject;
 
-    my $type    = $self->get('Content-Type') || '';
+    my $type    = $self->get('Content-Type', 0) || '';
     my $size    = $self->size;
     my $deleted = $self->label('deleted') ? ', deleted' : '';
 
@@ -64,11 +67,13 @@ sub printStructure(;$$)
 
     my $body    = $self->body;
     my @parts
-      = $body->isMultipart ? $body->parts
-      : $body->isNested    ? ($body->nested)
+      = $body->isNested    ? ($body->nested)
+      : $body->isMultipart ? $body->parts
       :                      ();
 
-    $_->printStructure($fh, $indent.'   ') foreach @parts;
+    $_->printStructure($fh, $indent.'   ')
+        for @parts;
+
     $buffer;
 }
     
