@@ -1,18 +1,19 @@
-# Copyrights 2001-2007 by Mark Overmeer.
-# For other contributors see ChangeLog.
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.04.
 use strict;
 use warnings;
 
 package Mail::Message::Field;
 use vars '$VERSION';
-$VERSION = '2.070';
+$VERSION = '2.082';
+
 use base 'Mail::Reporter';
 
 use Carp;
 use Mail::Address;
-use POSIX      'strftime';
+use Date::Format 'strftime';
 use IO::Handle;
 
 our %_structured;  # not to be used directly: call isStructured!
@@ -231,10 +232,10 @@ sub attribute($;$)
 
     unless(@_)
     {   if($body =~ m/\b$attr\s*\=\s*
-                      ( "( (?> [^\\"]*|\\. )* )"
+                      ( "( (?> [^\\"]+|\\. )* )"
                       | ([^";\s]*)
                       )/xi)
-        {   (my $val = $+) =~ s/(["\\])/\\$1/g;
+        {   (my $val = $+) =~ s/\\(.)/$1/g;
             return $val;
         }
         return undef;
@@ -307,7 +308,7 @@ sub toDate(@)
     my $time   = strftime($format, @time);
 
     # for C libs which do not (GNU compliantly) support %z
-    $time =~ s/ (\%z|[A-Z ]+)$/_tz_offset($1)/e;
+    $time =~ s/ (\%z|[A-Za-z ]+)$/_tz_offset($1)/e;
 
     $time; 
 }
@@ -449,6 +450,7 @@ sub fold($$;$)
     my $name  = shift;
     my $line  = shift;
     my $wrap  = shift || $default_wrap_length;
+    defined $line or $line = '';
 
     $line    =~ s/\n\s/ /gms;            # Remove accidental folding
     return " \n" unless CORE::length($line);  # empty field
