@@ -1,9 +1,14 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 use strict;
 use warnings;
 
 package Mail::Message::Field::Addresses;
 use vars '$VERSION';
-$VERSION = '2.055';
+$VERSION = '2.082';
+
 use base 'Mail::Message::Field::Structured';
 
 use Mail::Message::Field::AddrGroup;
@@ -113,15 +118,6 @@ sub addAttribute($;@)
 #------------------------------------------
 
 
-sub addExtra($@)
-{   my $self = shift;
-    $self->log(ERROR => 'No extras in address fields.');
-    $self;
-}
-
-#------------------------------------------
-
-
 sub parse($)
 {   my ($self, $string) = @_;
     my ($group, $email) = ('', undef);
@@ -187,12 +183,11 @@ sub parse($)
 
 #------------------------------------------
 
-
 sub produceBody()
 {  my @groups = sort {$a->name cmp $b->name} shift->groups;
 
-   return undef unless @groups;
-   return $groups[0]->string if @groups==1;
+   @groups     or return '';
+   @groups > 1 or return $groups[0]->string;
 
    my $plain
     = $groups[0]->name eq '' && $groups[0]->addresses
