@@ -1,13 +1,14 @@
-# Copyrights 2001-2007 by Mark Overmeer.
-# For other contributors see ChangeLog.
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.04.
 use strict;
 use warnings;
 
 package Mail::Message::Field::Full;
 use vars '$VERSION';
-$VERSION = '2.070';
+$VERSION = '2.082';
+
 use base 'Mail::Message::Field';
 
 use utf8;
@@ -21,6 +22,7 @@ use Mail::Message::Field::Addresses;
 use Mail::Message::Field::URIs;
 
 my $atext = q[a-zA-Z0-9!#\$%&'*+\-\/=?^_`{|}~];  # from RFC
+my $atext_ill = q/\[\]/;     # illegal, but still used (esp spam)
 
 
 use overload '""' => sub { shift->decodedBody };
@@ -63,7 +65,7 @@ sub new($;$$@)
 
     # Look for best class to suit this field
     my $myclass = 'Mail::Message::Field::'
-                . ($implementation{lc $name} || 'Unstructured');
+      . ($implementation{lc $name} || 'Unstructured');
 
     $myclass->SUPER::new(%args, name => $name, body => $body);
 }
@@ -84,19 +86,9 @@ sub init($)
     $self;
 }
 
-#------------------------------------------
-
 sub clone() { dclone(shift) }
-
-#------------------------------------------
-
-sub name() { lc shift->{MMFF_name}}
-
-#------------------------------------------
-
-sub Name() { shift->{MMFF_name}}
-
-#------------------------------------------
+sub name()  { lc shift->{MMFF_name}}
+sub Name()  { shift->{MMFF_name}}
 
 sub folded()
 {   my $self = shift;
@@ -108,8 +100,6 @@ sub folded()
     ($first, @lines);
 }
 
-#------------------------------------------
-
 sub unfoldedBody($;$)
 {   my ($self, $body) = (shift, shift);
 
@@ -124,8 +114,6 @@ sub unfoldedBody($;$)
     $body;
 }
 
-#------------------------------------------
-
 sub foldedBody($)
 {   my ($self, $body) = @_;
 
@@ -182,8 +170,6 @@ sub createComment($@)
     "($comment)";
 }
 
-#------------------------------------------
-
 
 sub createPhrase($)
 {   my $self = shift;
@@ -200,8 +186,6 @@ sub createPhrase($)
     $_;
 }
 
-#------------------------------------------
-
 
 sub beautify() { shift }
 
@@ -273,8 +257,6 @@ sub encode($@)
     $ready;
 }
 
-#------------------------------------------
-
 
 sub _decoder($$$)
 {   my ($charset, $encoding, $encoded) = @_;
@@ -317,18 +299,16 @@ sub decode($@)
 
 sub parse($) { shift }
 
-#------------------------------------------
-
 
 sub consumePhrase($)
 {   my ($thing, $string) = @_;
 
-    if($string =~ s/^\s*\"((?:[^"\\]*|\\.)*)\"// )
+    if($string =~ s/^\s*\" ((?:[^"\r\n\\]*|\\.)*) (?:\"|\s*$)//x )
     {   (my $phrase = $1) =~ s/\\\"/"/g;
         return ($phrase, $string);
     }
 
-    if($string =~ s/^\s*([$atext\ \t.]+)//o )
+    if($string =~ s/^\s*([${atext}${atext_ill}\ \t.]+)//o )
     {   (my $phrase = $1) =~ s/\s+$//;
         return CORE::length($phrase) ? ($phrase, $string) : (undef, $_[1]);
     }
@@ -336,8 +316,6 @@ sub consumePhrase($)
     (undef, $string);
 }
 
-#------------------------------------------
-
 
 sub consumeComment($)
 {   my ($thing, $string) = @_;
@@ -361,8 +339,6 @@ sub consumeComment($)
     ($comment, $string);
 }
 
-#------------------------------------------
-
 
 sub consumeDotAtom($)
 {   my ($self, $string) = @_;
@@ -380,10 +356,8 @@ sub consumeDotAtom($)
     ($atom, $string, $comment);
 }
 
-#------------------------------------------
 
-                                                                                
-sub produceBody() { die }
+sub produceBody() { $_[0]->{MMFF_body} }
 
 #------------------------------------------
 
