@@ -1,13 +1,14 @@
-# Copyrights 2001-2007 by Mark Overmeer.
-# For other contributors see ChangeLog.
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.04.
 use strict;
 use warnings;
 
 package Mail::Message::Field::Structured;
 use vars '$VERSION';
-$VERSION = '2.070';
+$VERSION = '2.082';
+
 use base 'Mail::Message::Field::Full';
 
 use Mail::Message::Field::Attribute;
@@ -34,8 +35,6 @@ sub init($)
     $self;
 }
 
-#------------------------------------------
-
 sub clone() { dclone(shift) }
 
 #------------------------------------------
@@ -62,17 +61,11 @@ sub attribute($;$)
     }
 }
 
-#------------------------------------------
-
 
 sub attributes() { values %{shift->{MMFS_attrs}} }
 
-#------------------------------------------
-
 sub beautify() { delete shift->{MMFF_body} }
 
-#------------------------------------------
-
 
 sub parse($)
 {   my ($self, $string) = @_;
@@ -85,7 +78,9 @@ sub parse($)
 
     my $found = '';
     while($string =~ m/\S/)
-    {   if($string =~ s/^\s*\;\s*// && length $found)
+    {   my $len = length $string;
+
+        if($string =~ s/^\s*\;\s*// && length $found)
         {   my $attr = Mail::Message::Field::Attribute->new($found);
             $self->attribute($attr);
             $found = '';
@@ -95,6 +90,11 @@ sub parse($)
         $string =~ s/^\n//;
         (my $text, $string) = $self->consumePhrase($string);
         $found .= $text if defined $text;
+
+        if(length($string) == $len)
+        {   # nothing consumed, remove character to avoid endless loop
+            $string =~ s/^\s*\S//;
+        }
     }
 
     if(length $found)
@@ -105,8 +105,6 @@ sub parse($)
     1;
 }
 
-#------------------------------------------
-
 sub produceBody()
 {   my $self  = shift;
     my $attrs = $self->{MMFS_attrs};
@@ -117,8 +115,6 @@ sub produceBody()
        , map {$_->string} @{$attrs}{sort keys %$attrs};
 }
 
-#------------------------------------------
-
 
 sub datum(;$)
 {   my $self = shift;
