@@ -1,13 +1,14 @@
-# Copyrights 2001-2007 by Mark Overmeer.
-# For other contributors see ChangeLog.
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 0.99.
+# Pod stripped from pm file by OODoc 1.04.
 use strict;
 use warnings;
 
 package Mail::Message::Head;
 use vars '$VERSION';
-$VERSION = '2.070';
+$VERSION = '2.082';
+
 use base 'Mail::Reporter';
 
 use Mail::Message::Head::Complete;
@@ -61,8 +62,6 @@ sub init($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub build(@)
 {   shift;
@@ -74,8 +73,6 @@ sub build(@)
 
 sub isDelayed { 1 }
 
-#------------------------------------------
-
 
 sub modified(;$)
 {   my $self = shift;
@@ -83,18 +80,12 @@ sub modified(;$)
     $self->{MMH_modified} = shift;
 }
 
-#------------------------------------------
-
 
 sub isModified() { shift->{MMH_modified} }
 
-#------------------------------------------
-
 
 sub isEmpty { scalar keys %{shift->{MMH_fields}} }
 
-#------------------------------------------
-
 
 sub message(;$)
 {   my $self = shift;
@@ -106,13 +97,9 @@ sub message(;$)
     $self->{MMH_message};
 }
 
-#------------------------------------------
-
 
 sub orderedFields() { grep {defined $_} @{shift->{MMH_order}} }
 
-#------------------------------------------
-
 
 sub knownNames() { keys %{shift->{MMH_fields}} }
 
@@ -145,8 +132,6 @@ sub get($;$)
 sub get_all(@) { my @all = shift->get(@_) }   # compatibility, force list
 sub setField($$) {shift->add(@_)} # compatibility
 
-#------------------------------------------
-
 
 sub study($;$)
 {   my $self = shift;
@@ -160,16 +145,12 @@ sub study($;$)
 #------------------------------------------
 
 
-#------------------------------------------
-
 
 sub isMultipart()
-{   my $type = shift->get('Content-Type');
+{   my $type = shift->get('Content-Type', 0);
     $type && scalar $type->body =~ m[^multipart/]i;
 }
 
-#------------------------------------------
-
 
 sub read($)
 {   my ($self, $parser) = @_;
@@ -185,8 +166,6 @@ sub read($)
     $self;
 }
 
-#------------------------------------------
-
 
 #  Warning: fields are added in addResentGroup() as well!
 sub addOrderedFields(@)
@@ -198,21 +177,15 @@ sub addOrderedFields(@)
     @_;
 }
 
-#------------------------------------------
-
 
 sub load($) {shift}
 
-#------------------------------------------
-
 
 sub fileLocation()
 {   my $self = shift;
     @$self{ qw/MMH_begin MMH_end/ };
 }
 
-#------------------------------------------
-
 
 sub moveLocation($)
 {   my ($self, $dist) = @_;
@@ -221,8 +194,6 @@ sub moveLocation($)
     $self;
 }
 
-#------------------------------------------
-
 
 sub setNoRealize($)
 {   my ($self, $field) = @_;
@@ -235,8 +206,6 @@ sub setNoRealize($)
     $field;
 }
 
-#------------------------------------------
-
 
 sub addNoRealize($)
 {   my ($self, $field) = @_;
