@@ -1,9 +1,14 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 use strict;
 use warnings;
 
 package Mail::Message::Head::Complete;
 use vars '$VERSION';
-$VERSION = '2.068';
+$VERSION = '2.082';
+
 use base 'Mail::Message::Head';
 
 use Mail::Box::Parser;
@@ -17,7 +22,7 @@ sub clone(;@)
 {   my $self   = shift;
     my $copy   = ref($self)->new($self->logSettings);
 
-    $copy->addNoRealize($_->clone) foreach $self->orderedFields;
+    $copy->addNoRealize($_->clone) for $self->grepNames(@_);
     $copy->modified(1);
     $copy;
 }
@@ -135,7 +140,7 @@ sub grepNames(@)
     my @take;
     push @take, (ref $_ eq 'ARRAY' ? @$_ : $_) foreach @_;
 
-    return $self->names unless @take;
+    return $self->orderedFields unless @take;
 
     my $take;
     if(@take==1 && ref $take[0] eq 'Regexp')
@@ -147,7 +152,7 @@ sub grepNames(@)
         $take    = qr/^(?:(?:@take))/i;
     }
 
-    grep {$_->Name =~ $take} $self->orderedFields;
+    grep {$_->name =~ $take} $self->orderedFields;
 }
 
 #------------------------------------------
