@@ -1,14 +1,20 @@
+# Copyrights 2001-2008 by Mark Overmeer.
+#  For other contributors see ChangeLog.
+# See the manual pages for details on the licensing terms.
+# Pod stripped from pm file by OODoc 1.04.
 
 use strict;
 use warnings;
 
 package Mail::Transport::IMAP4;
 use vars '$VERSION';
-$VERSION = '2.063';
+$VERSION = '2.082';
+
 use base 'Mail::Transport::Receive';
 
 use Digest::HMAC_MD5;   # only availability check for CRAM_MD5
 use Mail::IMAPClient;
+use List::Util        qw/first/;
 
 
 sub init($)
@@ -40,8 +46,6 @@ sub init($)
     $self->login             or return undef;
 }
 
-#------------------------------------------
-
 
 sub url()
 {   my $self = shift;
@@ -53,15 +57,15 @@ sub url()
 #------------------------------------------
 
 
-our $ntml_installed;
+our $ntlm_installed;
 
 sub authentication(@)
 {   my ($self, @types) = @_;
 
-    unless(defined $ntml_installed)
-    {   eval "require Authen::NTML";
-        die "NTML errors:\n$@" if $@ && $@ !~ /Can't locate/;
-        $ntml_installed = ! $@;
+    unless(defined $ntlm_installed)
+    {   eval "require Authen::NTLM";
+        die "NTLM errors:\n$@" if $@ && $@ !~ /Can't locate/;
+        $ntlm_installed = ! $@;
     }
 
     # What the client wants to use to login
@@ -71,7 +75,7 @@ sub authentication(@)
     }
 
     if(@types == 1 && $types[0] eq 'AUTO')
-    {   @types = ('CRAM-MD5', ($ntml_installed ? 'NTLM' : ()), 'PLAIN');
+    {   @types = ('CRAM-MD5', ($ntlm_installed ? 'NTLM' : ()), 'PLAIN');
     }
 
     $self->{MTI_auth} = \@types;
@@ -79,9 +83,9 @@ sub authentication(@)
     my @clientside;
     foreach my $auth (@types)
     {   push @clientside
-           , ref $auth eq 'ARRAY' ? $auth
-           : $auth eq 'NTLM'      ? [NTLM  => \&Authen::NTLM::ntlm ]
-           :                        [$auth => undef];
+         , ref $auth eq 'ARRAY' ? $auth
+         : $auth eq 'NTLM'      ? [NTLM  => \&Authen::NTLM::ntlm ]
+         :                        [$auth => undef];
     }
 
     my %clientside = map { ($_->[0] => $_) } @clientside;
@@ -89,12 +93,12 @@ sub authentication(@)
     # What does the server support? in its order of preference.
 
     my $imap = $self->imapClient or return ();
-    my @serverside = map { m/^AUTH=(\w+)/ ? uc($1) : () }
+    my @serverside = map { m/^AUTH=(\S+)/ ? uc($1) : () }
                         $imap->capability;
 
     my @auth;
     if(@serverside)  # server list auth capabilities
-    {   @auth = map { $clientside{$_->[0]} ? delete $clientside{$_->[0]} : () }
+    {   @auth = map { $clientside{$_} ? delete $clientside{$_} : () }
              @serverside;
     }
     @auth = @clientside unless @auth;  # fallback to client's preference
@@ -102,8 +106,6 @@ sub authentication(@)
     @auth;
 }
 
-#------------------------------------------
-
 
 sub domain(;$)
 {   my $self = shift;
@@ -114,16 +116,11 @@ sub domain(;$)
 #------------------------------------------
 
 
-#------------------------------------------
-
-
 sub imapClient(;$)
 {   my $self = shift;
     @_ ? ($self->{MTI_client} = shift) : $self->{MTI_client};
 }
 
-#------------------------------------------
-
 
 sub createImapClient($)
 {   my ($self, $class) = @_;
@@ -149,8 +146,6 @@ sub createImapClient($)
     $client;
 }
 
-#------------------------------------------
-
 
 sub login(;$)
 {   my $self = shift;
@@ -215,33 +210,76 @@ sub login(;$)
     undef;
 }
 
-#------------------------------------------
 
-
-sub folder(;$)
+sub currentFolder(;$)
 {   my $self = shift;
     return $self->{MTI_folder} unless @_;
 
     my $name = shift;
-    return $name if $name eq ($self->{MTI_folder} || '/');
+
+    if(exists $self->{MTI_folder} && $name eq $self->{MTI_folder})
+    {   $self->log(DEBUG => "Folder $name already selected.");
+        return $name;
+    }
+
+    # imap first deselects the old folder so if the next call
+    # fails the server will not have anything selected.
+    $self->{MTI_folder} = undef;
 
     my $imap = $self->imapClient or return;
-    $imap->select($name)         or return;
-    $self->{MTI_folder} = $name;
-    $imap;
-}
 
-#------------------------------------------
+    if($name eq '/' || $imap->select($name))
+    {   $self->{MTI_folder} = $name;
+        $self->log(NOTICE => "Selected folder $name");
+        return 1;
+    }
+
+    # Just because we couldn't select the folder that doesn't mean it doesn't
+    # exist.  It just means that this particular imap client is warning us
+    # that it can't contain messages.  So we'll verify that it does exist
+    # and, if so, we'll pretend like we could have selected it as if it were
+    # a regular folder.
+    # IMAPClient::exists() only works reliably for leaf folders so we need
+    # to grep for it ourselves.
+
+    if(first { $_ eq $name } $self->folders)
+    {   $self->{MTI_folder} = $name;
+        $self->log(NOTICE => "Couldn't select $name but it does exist.");
+        return 0;
+    }
+
+    $self->log(NOTICE => "Folder $name does not exist!");
+    undef;
+}
 
 
 sub folders(;$)
 {   my $self = shift;
-    my $imap = $self->imapClient or return ();
-    my @top  = @_ && $_[0] eq '/' ? () : shift;
-    $imap->folders(@top);
-}
+    my $top  = shift;
 
-#------------------------------------------
+    my $imap = $self->imapClient or return ();
+    $top = undef if defined $top && $top eq '/';
+
+    # We need to force the remote IMAP client to only return folders
+    # *underneath* the folder we specify.  By default they want to return
+    # all folders.
+    # Alas IMAPClient always appends the separator so, despite what it says
+    # in its own docs, there's purpose to doing this.  We just need
+    # to get whatever we get and postprocess it.
+    my @folders = $imap->folders($top);
+
+    # We need to post-process the list returned by IMAPClient.
+    # This selects out the level of directories we're interested in.
+    my $sep   = $imap->separator;
+    my $level = 1 + (defined $top ? () = $top =~ m/\Q$sep\E/g : -1);
+
+    # There may be multiples thanks to subdirs so we uniq it
+    my %uniq;
+    $uniq{(split($sep, $_))[$level]||''}++ foreach @folders;
+    delete $uniq{''};
+
+    keys %uniq;
+}
 
 
 sub ids($)
@@ -250,8 +288,6 @@ sub ids($)
     $imap->messages;
 }
 
-#------------------------------------------
-
 
 # Explanation in Mail::Box::IMAP4::Message chapter DETAILS
 
@@ -291,13 +327,9 @@ sub getFlags($$)
     $labels;
 }
 
-#------------------------------------------
-
 
 sub listFlags() { keys %flags2labels }
 
-#------------------------------------------
-
 
 # Mail::IMAPClient can only set one value a time, however we do more...
 sub setFlags($@)
@@ -325,8 +357,6 @@ sub setFlags($@)
     @nonstandard;
 }
 
-#------------------------------------------
-
 
 sub labelsToFlags(@)
 {   my $thing = shift;
@@ -351,8 +381,6 @@ sub labelsToFlags(@)
     join " ", sort @set;
 }
 
-#------------------------------------------
-
 
 sub flagsToLabels($@)
 {   my ($thing, $what) = (shift, shift);
@@ -382,8 +410,6 @@ sub flagsToLabels($@)
     wantarray ? %labels : \%labels;
 }
 
-#------------------------------------------
-
 
 sub getFields($@)
 {   my ($self, $id) = (shift, shift);
@@ -398,8 +424,6 @@ sub getFields($@)
     @fields;
 }
 
-#------------------------------------------
-
 
 sub getMessageAsString($)
 {   my $imap = shift->imapClient or return;
@@ -407,8 +431,6 @@ sub getMessageAsString($)
     $imap->message_string($uid);
 }
 
-#------------------------------------------
-
 
 sub fetch($@)
 {   my ($self, $msgs, @info) = @_;
@@ -455,8 +477,6 @@ sub fetch($@)
     values %msgs;
 }
 
-#------------------------------------------
-
 
 sub appendMessage($$)
 {   my ($self, $message, $foldername) = @_;
@@ -468,15 +488,20 @@ sub appendMessage($$)
      );
 }
 
-#------------------------------------------
 
+sub destroyDeleted($)
+{   my ($self, $folder) = @_;
+    defined $folder or return;
 
-sub destroyDeleted()
-{   my $imap = shift->imapClient or return ();
-    $imap->expunge;
+    my $imap = shift->imapClient or return;
+    $imap->expunge($folder);
 }
 
-#------------------------------------------
+
+sub createFolder($)
+{   my $imap = shift->imapClient or return ();
+    $imap->create(shift);
+}
 
 
 sub deleteFolder($)
@@ -484,8 +509,6 @@ sub deleteFolder($)
     $imap->delete(shift);
 }
 
-#------------------------------------------
-
 
 sub DESTROY()
 {   my $self = shift;
